@@ -1543,7 +1543,7 @@ sub write_invest {
     if ($name =~ /^$::REG_INVESTIG$/o) {
         print INVES "$name\n";
     } else {
-        print_err ("Invalid investigator: $name<br>\n".
+        Print::print_err ("Invalid investigator: $name<br>\n".
           "Use the browser's back button to fix");
     }
     close (INVES);
@@ -2554,7 +2554,7 @@ sub img_makestr {
     alarm(5);
 
 	Exec::exec_pipe (*OUT,
-	  "'$::STRINGS_EXE' -a -t d '$img' > '$fname'");
+	  "'$::STRINGS_EXE' -a $::STR_DEC '$img' > '$fname'");
 	print $_ while ($_ = Exec::read_pipe_line(*OUT));
 	close (OUT);
 
