@@ -714,6 +714,7 @@ EOF3
 
 
 	my $cnt = 0;
+	my %seen;
 
 	# sort into arrays
 	while ($_ = Exec::read_pipe_line(*OUT) ) {
@@ -740,6 +741,106 @@ EOF3
 				$meta_int[$cnt] = $meta[$cnt];
 			}
 
+
+			# See if we have already seen this file yet
+			if (exists $seen{"$name[$cnt]-$meta[$cnt]"}) {
+				my $prev_cnt = $seen{"$name[$cnt]-$meta[$cnt]"};
+
+				# If we saw it while it was deleted, & it
+				# is now undel, then update it
+				if (($del[$cnt] eq "") &&
+				  ($del[$prev_cnt] eq '*')) {
+					$del[$prev_cnt] = $del[$cnt];
+				}
+				next;
+
+			# Add it to the seen list
+			} else {
+				$seen{"$name[$cnt]-$meta[$cnt]"} = $cnt;
+			}
+
+
+			# We must adjust the dir for directories
+			if ($itype[$cnt] eq 'd') {
+				# special cases for .. and .
+				if ($name[$cnt] eq '..') {
+					my @dirs = split ('/', $lcldir);
+					my $i;
+					$lcldir = "";
+					for ($i = 0; $i < $#dirs; $i++) {
+						$lcldir .= ($dirs[$i].'/');
+					}
+				}
+				elsif ($name[$cnt] ne '.') {
+					$lcldir .= ($name[$cnt].'/');
+				}
+				$name[$cnt] .= '/';
+			}
+			else {
+				$lcldir .= $name[$cnt];
+			}
+
+
+			# format the date so that the time and time zone are on the
+			# same line
+			$mod[$cnt] = "$1&nbsp;$2"  
+			  if ($mod[$cnt] =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+
+			$acc[$cnt] = "$1&nbsp;$2"  
+			  if ($acc[$cnt] =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+
+			$chg[$cnt] = "$1&nbsp;$2"  
+			  if ($chg[$cnt] =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+
+			$dir[$cnt] = Args::url_encode($lcldir);
+			$entry[$cnt] = $cnt;
+			$cnt++;
+
+		} 
+		# We missed it for some reason
+		else {
+			print "<tr><td colspan=10>Error Parsing File (Invalid Characters?):<br>$_</td></tr>\n";
+		}
+	}
+	close (OUT);
+
+	if ($ftype eq "ntfs") {
+
+
+	Exec::exec_pipe(*OUT, "'$::TSKDIR/ifind' -f $ftype -l $tz -p $meta '$img'");
+
+	while ($_ = Exec::read_pipe_line(*OUT) ) {
+		if (/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o) {
+
+			my $lcldir = $Args::args{'dir'};
+			$dtype[$cnt] = $1;
+			$itype[$cnt] = $2;
+			$del[$cnt] = $3;
+			$meta[$cnt] = $4;
+			$realloc[$cnt] = "";
+			$realloc[$cnt] = $5 if (defined $5);
+			$name[$cnt] = $6;
+			$mod[$cnt] = $7;
+			$acc[$cnt] = $8;
+			$chg[$cnt] = $9;
+			$size[$cnt] = $10;
+			$gid[$cnt] = $11;
+			$uid[$cnt] = $12;
+
+			if ($meta[$cnt] =~ /^(\d+)(-\d+(-\d+)?)?$/) {
+				$meta_int[$cnt] = $1;
+			} else {
+				$meta_int[$cnt] = $meta[$cnt];
+			}
+
+			# See if we have already seen this file yet
+			if (exists $seen{"$name[$cnt]-$meta[$cnt]"}) {
+				next;
+			# Add it to the seen list
+			} else {
+				$seen{"$name[$cnt]-$meta[$cnt]"} = $cnt;
+			}
+
 			# We must adjust the dir for directories
 			if ($itype[$cnt] eq 'd') {
 				# special cases for .. and .
@@ -782,13 +883,15 @@ EOF3
 			print "<tr><td colspan=10>Error Parsing File (Invalid Characters?):<br>$_</td></tr>\n";
 		}
 	}
+	close (OUT);
+
+	} # NTFS ONLY
 
 	if ($cnt == 0) {
 		print "</table>\n<center>No Contents</center>\n";
 		return 0;
 	}
 
-	close (OUT);
 
 	# Sort the above array based on the sort argument
 	my @sorted;	# an array of indices
@@ -977,7 +1080,8 @@ sub file_list_dir {
 	while ($_ = Exec::read_pipe_line(*OUT) ) {
 
 		# This is a directory 
-		if ((/mode:\s+d/)  || (/File Attributes: Directory/)) {
+		if ((/mode:\s+d/)  || (/File Attributes: Directory/) ||
+		  (/^Flags:.*?Directory/)) {
 			close (OUT);
 
 			# Set the meta variables
@@ -999,19 +1103,39 @@ sub file_list_dir {
 	# This is not a directory, so just give a link
 	Print::print_html_header("");
 
+
+
+	my $recmode = $File::REC_NO;
+	local *OUT;
+	Exec::exec_pipe(*OUT, "'$::TSKDIR/ils' -f $ftype -e '$img' $meta");
+	while ( $_ = Exec::read_pipe_line(*OUT) ) {
+		chop ;
+		next unless ($_ =~ /^$meta/);
+		if ($_ =~ /^$meta\|f/) {
+			$recmode = $File::REC_YES;
+		}
+		elsif ($_ =~ /^$meta\|a/) {
+			$recmode = $File::REC_NO;
+		}
+		else {
+			Print::print_err("Error parsing ils output: $_");
+		}
+	}
+	close (OUT);
+
+
 print <<EOF;
 
 <tt>$dir</tt> (
-<a href=\"$::PROGNAME?mod=$::MOD_FRAME&submod=$::MOD_META&$Args::baseargs&meta=$meta\" target=\"_top\">
+<a href=\"$::PROGNAME?mod=$::MOD_FRAME&submod=$::MOD_META&$Args::baseargs&meta=$meta&recmode=$recmode\" target=\"_top\">
 meta $meta</a>) is not a directory.
 
 <p>
-<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT_FR&$Args::baseargs&meta=$meta&dir=$dir\" target=\"content\">
+<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT_FR&$Args::baseargs&meta=$meta&dir=$dir&recmode=$recmode\" target=\"content\">
   <img src=\"pict/but_viewcont.jpg\" height=20 width=123 alt=\"view contents\" border=\"0\">
 </a>
 
 EOF
-# @@@ The above link will not have file recovery enabled
 
     Print::print_html_footer();
 	return 1;
