@@ -488,7 +488,7 @@ sub run {
 	if (length($orig_str) < 4) {
 		my $ltmp = length ($orig_str);
 		Exec::exec_pipe (*OUT, 
-		  "'$::STRINGS_EXE' -t d -n $ltmp '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+		  "'$::STRINGS_EXE' -a $::STR_DEC -$ltmp '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
 	}
 	# Use the strings file if it exists
 	elsif (defined $Caseman::img2str{$Args::args{'img'}}) {
@@ -499,7 +499,7 @@ sub run {
 	# Run strings on the image first and then grep that
 	else {
 		Exec::exec_pipe (*OUT, 
-		  "'$::STRINGS_EXE' -a -t d '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+		  "'$::STRINGS_EXE' -a $::STR_DEC '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
 	} 
 
 
