@@ -384,7 +384,7 @@ sub stats {
 				next;
 			}
 			elsif (/^Type: (\S+) \((\d+\-\d+)\) (.*)$/) {
-				print "Type: $1 (".
+				print "$1 (".
 				  "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT_FR&$Args::baseargs".
 				  "&meta=$meta_int-$2&dir=$Args::args{'img'}-meta-$meta_int-$2\" ".
 				  "target=\"_blank\">$2</a>) $3<br>\n";
